from __future__ import absolute_import, unicode_literals

from django.conf import settings
from django.conf.urls import include, url

from wagtail.admin import urls as wagtailadmin_urls
from wagtail.core import urls as wagtail_urls
from wagtail.documents import urls as wagtaildocs_urls

urlpatterns = []

urlpatterns += [
    url(r'^admin/', include(wagtailadmin_urls)),
    url(r'^documents/', include(wagtaildocs_urls)),
    url(r'', include(wagtail_urls)),
]

if settings.DEBUG:
    from django.conf.urls.static import static
    from django.contrib.staticfiles.urls import staticfiles_urlpatterns

    # Serve static and media files from development server
    urlpatterns += staticfiles_urlpatterns()
    urlpatterns += static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)



from django.db import models
from modelcluster.fields import ParentalKey
from django.conf import settings

from .abstract_advanced_form_field import AbstractAdvancedFormField

DEFAULT_FORM_PAGE_MODEL = 'wagtail_advanced_form_builder.FormPage'


class FormField(AbstractAdvancedFormField):

    page = ParentalKey(
        getattr(settings, 'ADVANCED_FORMS_FORM_PAGE_MODEL', DEFAULT_FORM_PAGE_MODEL),
        on_delete=models.CASCADE,
        related_name='form_fields'
    )



from __future__ import absolute_import, unicode_literals
from wagtail.core.models import Page

class HomePage(Page):
    subpage_types = [
        'wagtail_advanced_form_builder.EmailFormPage',
        'wagtail_advanced_form_builder.FormPage',
    ]




# Generated by Django 2.2.14 on 2020-10-07 03:41

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('wagtail_advanced_form_builder', '0006_auto_20201007_1626'),
    ]

    operations = [
        migrations.AddField(
            model_name='abstractadvancedemailform',
            name='use_browser_validation',
            field=models.BooleanField(blank=True, default=False, help_text='Tick this to use the in-built browser validation on fields'),
        ),
        migrations.AddField(
            model_name='abstractadvancedform',
            name='use_browser_validation',
            field=models.BooleanField(blank=True, default=False, help_text='Tick this to use the in-built browser validation on fields'),
        ),
    ]



from django.forms import  Widget


class HTMLOutputWidget(Widget):

    html_value = None

    template_name = "wagtail_advanced_form_builder/widgets/html_output_widget.html"

    def __init__(self, html_value=None, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.html_value = html_value

    def get_context(self, *args, **kwargs):

        context = super().get_context(*args, **kwargs)

        context['widget'].update({
            'html_value': self.html_value,
        })

        return context



from wagtail_advanced_form_builder.blocks.base_static_block import BaseStaticBlock


class InlineFormBlock(BaseStaticBlock):
    """
    This block allows the user to position the form amongst other content on the page
    """
    class Meta:
        template = 'wagtail_advanced_form_builder/blocks/inline_form_block.html'
        icon = 'form'
        help_text = 'This will insert the form for this page into this position. ' \
                    'You can only add this block once on this page.'
        form_classname = ''



from django.apps import AppConfig as DjangoAppConfig


class BuildTestAppConfig(DjangoAppConfig):
    name = 'build_test'
    label = "build_test"
    verbose_name = "Wagtail Advanced Forms Test app"



from django.utils.translation import ugettext_lazy as _

from wagtail.admin.edit_handlers import MultiFieldPanel, FieldRowPanel, FieldPanel
from wagtail.contrib.forms.models import AbstractEmailForm
from .abstract_advanced_form_mixin import AbstractAdvancedFormMixin
from .email_form_field import EmailFormField

class AbstractAdvancedEmailForm(AbstractAdvancedFormMixin, AbstractEmailForm):

    form_field = EmailFormField

    content_panels = AbstractAdvancedFormMixin.content_panels + [
        MultiFieldPanel([
            FieldRowPanel([
                FieldPanel('from_address', classname='col6'),
                FieldPanel('to_address', classname='col6')
            ]),
            FieldPanel('subject'),
        ], _('Email')),
    ]

    settings_panels = AbstractAdvancedFormMixin.settings_panels
